# This file is part of the Biopython distribution and governed by your
# choice of the "Biopython License Agreement" or the "BSD 3-Clause License".
# Please see the LICENSE file that should have been included as part of this
# package.
"""A selection of Hidden Markov Model code."""

# File needed on Python 2 to import anything else in this directory
